==> discord-ext-ui-1.1.0.tar.gz: discord-ext-ui-1.1.0/setup.py <==
from setuptools import setup
import re

version = ''
with open('discord/ext/ui/__init__.py') as f:
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]', f.read(), re.MULTILINE).group(1)

if not version:
    raise RuntimeError('version is not set')

if version.endswith(('a', 'b', 'rc')):
    # append version identifier based on commit count
    try:
        import subprocess

        p = subprocess.Popen(['git', 'rev-list', '--count', 'HEAD'],
                             stdout=subprocess.PIPE, stderr=subprocess.PIPE)
        out, err = p.communicate()
        if out:
            version += out.decode('utf-8').strip()
        p = subprocess.Popen(['git', 'rev-parse', '--short', 'HEAD'],
                             stdout=subprocess.PIPE, stderr=subprocess.PIPE)
        out, err = p.communicate()
        if out:
            version += '+g' + out.decode('utf-8').strip()
    except Exception:
        pass

readme = ''
with open('README.rst') as f:
    readme = f.read()


setup(name='discord-ext-ui',
      author='sizumita',
      url='https://github.com/sizumita/discord-ext-ui',
      version=version,
      long_description=readme,
      long_description_content_type="text/x-rst",
      packages=['discord.ext.ui', 'discord.ext.ui.combine'],
      license='MIT',
      description='An Declarative UI Kit for discord.py',
      install_requires=[],
      python_requires='>=3.8.2',
      classifiers=[
        'Development Status :: 5 - Production/Stable',
        'License :: OSI Approved :: MIT License',
        'Intended Audience :: Developers',
        'Natural Language :: Japanese',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Internet',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities',
        ]
      )

==> discord-ext-ui-3.0.0.tar.gz: discord-ext-ui-3.0.0/setup.py <==
from setuptools import setup
import re

version = ''
with open('discord/ext/ui/__init__.py') as f:
    version = re.search(
        r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]',
        f.read(),
        re.MULTILINE).group(1)

if not version:
    raise RuntimeError('version is not set')

if version.endswith(('a', 'b', 'rc')):
    # append version identifier based on commit count
    try:
        import subprocess

        p = subprocess.Popen(['git', 'rev-list', '--count', 'HEAD'],
                             stdout=subprocess.PIPE, stderr=subprocess.PIPE)
        out, err = p.communicate()
        if out:
            version += out.decode('utf-8').strip()
        p = subprocess.Popen(['git', 'rev-parse', '--short', 'HEAD'],
                             stdout=subprocess.PIPE, stderr=subprocess.PIPE)
        out, err = p.communicate()
        if out:
            version += '+g' + out.decode('utf-8').strip()
    except Exception:
        pass

readme = ''
with open('README.rst') as f:
    readme = f.read()

test_requires = ['pytest>=6.2.4', 'mypy>=0.812', 'flake8>=3.9.2', 'tox']

setup(
    name='discord-ext-ui',
    author='sizumita',
    url='https://github.com/sizumita/discord-ext-ui',
    version=version,
    long_description=readme,
    long_description_content_type="text/x-rst",
    packages=['discord.ext.ui', 'discord.ext.ui.combine'],
    license='MIT',
    description='An Declarative UI Kit for pycord',
    install_requires=[],
    test_require=test_requires,
    python_requires='>=3.8.2',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'License :: OSI Approved :: MIT License',
        'Intended Audience :: Developers',
        'Natural Language :: Japanese',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Internet',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities',
    ]
)
